@@ -48,7 +48,7 @@ OC.L10N.register(
     "There was an error while setting up your account" : "Der opstod en fejl under opsætning af din konto",
     "Auto" : "Auto",
     "Name" : "Navn",
-    "Mail address" : "Mail addresse",
+    "Mail address" : "Mail adresse",
     "name@example.org" : "name@example.org",
     "Please enter an email of the format name@example.com" : "Indtast venligst en e-mail med formatet navn@eksempel.com",
     "Password" : "Kodeord",
@@ -245,14 +245,15 @@ OC.L10N.register(
     "View source" : "Vis kildekode",
     "Unnamed" : "Unavngiven",
     "Embedded message" : "Indlejret besked",
-    "Choose a folder to store the attachment in" : "Vælg den mappe, hvor vedhæftningen skal gemmes i",
-    "Import into calendar" : "Importere til kalender",
+    "Choose a folder to store the attachment in" : "Vælg den mappe, som vedhæftningen skal gemmes i",
+    "Import into calendar" : "Importér til kalender",
     "Download attachment" : "Hent vedhæftning",
     "Save to Files" : "Gem til filer",
     "Choose a folder to store the attachments in" : "Vælg den mappe, hvor vedhæftningerne skal gemmes i",
     "Save all to Files" : "Gem alle filer",
-    "The images have been blocked to protect your privacy." : "Dette billede er blevet blokeret for at beskytte din privat liv",
+    "The images have been blocked to protect your privacy." : "Dette billede er blevet blokeret for at beskytte dit privatliv.",
     "Show images" : "Vis billeder",
+    "Quoted text" : "Noteret tekst",
     "Move" : "Flyt",
     "Loading …" : "Indlæser…",
     "Remove account" : "Fjern konto",
@@ -269,8 +270,8 @@ OC.L10N.register(
     "_{total} message_::_{total} messages_" : ["{total} besked","{total} beskeder"],
     "Clear mailbox {name}" : "Ryd postkasse {name}",
     "Clear mailbox" : "Ryd postkasse",
-    "Mark all as read" : "Marker alle som læst",
-    "Mark all messages of this mailbox as read" : "Marker alle beskeder i denne postkasse som læst",
+    "Mark all as read" : "Markér alle som læst",
+    "Mark all messages of this mailbox as read" : "Markér alle beskeder i denne postkasse som læst",
     "Add submailbox" : "Tilføj underpostkasse",
     "Rename" : "Omdøb",
     "Clear cache" : "Ryd cache",
@@ -296,6 +297,7 @@ OC.L10N.register(
     "New Contact" : "Ny kontakt",
     "Copy to clipboard" : "Kopier til udklipsholder",
     "Add" : "Tilføj",
+    "Show less" : "Vis mindre",
     "Clear" : "Ryd",
     "Search in mailbox" : "Søg i postkasse",
     "Close" : "Luk",
@@ -329,6 +331,8 @@ OC.L10N.register(
     "Delete message" : "Slet besked",
     "Message source" : "Beskedens kildekode",
     "Go to newest message" : "Gå til nyeste besked",
+    "Translate from" : "Oversæt fra",
+    "Translate to" : "Oversæt til",
     "Copy translated text" : "Kopier oversat tekst",
     "Untitled event" : "Unavngiven begivenhed",
     "(organizer)" : "(arrangør)",
@@ -392,7 +396,7 @@ OC.L10N.register(
     "Could not load the desired message" : "Den ønskede besked kunne ikke indlæses",
     "Could not load the message" : "Beskeden kunne ikke indlæses",
     "Error loading message" : "Fejl under indlæsning af besked",
-    "Forwarding to %s" : "Videre send til %s",
+    "Forwarding to %s" : "Videresender til %s",
     "Click here if you are not automatically redirected within the next few seconds." : "Klik her hvis du ikke automatisk bliver videre sendt i løbet af et par sekunder.",
     "Redirect" : "Omdiriger",
     "The link leads to %s" : "Linket fører til %s",
