@@ -30,29 +30,6 @@ OC.L10N.register(
     "Archived messages are moved in:" : "Los mensajes archivados se mueven a:",
     "Snoozed messages are moved in:" : "Los mensajes pausados se mueven a:",
     "Junk messages are saved in:" : "Los mensajes \"basura\" se guardan en:",
-    "Auto" : "Auto",
-    "Name" : "Nombre",
-    "Mail address" : "Dirección de correo",
-    "name@example.org" : "nombre@ejemplo.org",
-    "Please enter an email of the format name@example.com" : "Por favor, ingresa un correo electrónico en el formato nombre@ejemplo.com",
-    "Password" : "Contraseña",
-    "Manual" : "Manual",
-    "IMAP Settings" : "Configuración IMAP",
-    "IMAP Host" : "Servidor IMAP",
-    "IMAP Security" : "Seguridad IMAP",
-    "None" : "Ninguno",
-    "SSL/TLS" : "SSL/TLS",
-    "STARTTLS" : "STARTTLS",
-    "IMAP Port" : "Puerto IMAP",
-    "IMAP User" : "Usuario IMAP",
-    "IMAP Password" : "Contraseña IMAP",
-    "SMTP Settings" : "Configuración SMTP",
-    "SMTP Host" : "Servior SMTP",
-    "SMTP Security" : "Seguridad SMTP",
-    "SMTP Port" : "Puerto SMTP",
-    "SMTP User" : "Usuario SMTP",
-    "SMTP Password" : "Contraseña SMTP",
-    "For the Google account to work with this app you need to enable two-factor authentication for Google and generate an app password." : "Para que la cuenta de Google funcione con esta aplicación, debes habilitar la autenticación en dos pasos para Google y generar una contraseña de aplicación.",
     "Connecting" : "Conectando",
     "Reconnect Google account" : "Reconectar cuenta de Google",
     "Sign in with Google" : "Iniciar sesión con Google",
@@ -81,6 +58,29 @@ OC.L10N.register(
     "Authorization pop-up closed" : "La ventana emergente de autorización fue cerrada",
     "Configuration discovery temporarily not available. Please try again later." : "Descubrimiento de configuración no disponible temporalmente. Por favor intenta más tarde.",
     "There was an error while setting up your account" : "Hubo un error al configurar tu cuenta",
+    "Auto" : "Auto",
+    "Name" : "Nombre",
+    "Mail address" : "Dirección de correo",
+    "name@example.org" : "nombre@ejemplo.org",
+    "Please enter an email of the format name@example.com" : "Por favor, ingresa un correo electrónico en el formato nombre@ejemplo.com",
+    "Password" : "Contraseña",
+    "Manual" : "Manual",
+    "IMAP Settings" : "Configuración IMAP",
+    "IMAP Host" : "Servidor IMAP",
+    "IMAP Security" : "Seguridad IMAP",
+    "None" : "Ninguno",
+    "SSL/TLS" : "SSL/TLS",
+    "STARTTLS" : "STARTTLS",
+    "IMAP Port" : "Puerto IMAP",
+    "IMAP User" : "Usuario IMAP",
+    "IMAP Password" : "Contraseña IMAP",
+    "SMTP Settings" : "Configuración SMTP",
+    "SMTP Host" : "Servior SMTP",
+    "SMTP Security" : "Seguridad SMTP",
+    "SMTP Port" : "Puerto SMTP",
+    "SMTP User" : "Usuario SMTP",
+    "SMTP Password" : "Contraseña SMTP",
+    "For the Google account to work with this app you need to enable two-factor authentication for Google and generate an app password." : "Para que la cuenta de Google funcione con esta aplicación, debes habilitar la autenticación en dos pasos para Google y generar una contraseña de aplicación.",
     "Account settings" : "Configuración de la cuenta",
     "Aliases" : "Aliases",
     "Alias to S/MIME certificate mapping" : "Asignación de alias a certificados S/MIME",
@@ -94,7 +94,6 @@ OC.L10N.register(
     "Days after which messages in Trash will automatically be deleted:" : "Días tras los cuales se borrarán automáticamente los mensajes de la papelera",
     "Autoresponder" : "Respuesta automática",
     "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Respuesta automática a mensajes entrantes. Si alguien te envía varios mensajes, esta respuesta automática se enviará como máximo una vez cada 4 días.",
-    "Please connect to a sieve server first." : "Por favor, conecta primero con un servidor Sieve.",
     "Filters" : "Filtros",
     "Sieve script editor" : "Editor de scripts Sieve",
     "Mail server" : "Servidor de correo",
@@ -110,6 +109,13 @@ OC.L10N.register(
     "Add alias" : "Añadir alias",
     "Create alias" : "Crear alias",
     "Cancel" : "Cancelar",
+    "Search in the body of messages in priority Inbox" : "Busca en el cuerpo de los mensajes de la bandeja de entrada prioritaria",
+    "Activate" : "Activar",
+    "Put my text to the bottom of a reply instead of on top of it." : "Pon el texto al fondo de una respuesta, en lugar de arriba.",
+    "Mark as important" : "Marcar como importante",
+    "Remind about messages that require a reply but received none" : "Recordar mensajes que requieren una respuesta pero no han recibido ninguna",
+    "Use internal addresses" : "Usar direcciones internas",
+    "Could not update preference" : "No se pudo actualizar la preferencia",
     "Mail settings" : "Configuración de correo",
     "Accounts" : "Cuentas",
     "Add mail account" : "Agregar cuenta de correo",
@@ -143,6 +149,7 @@ OC.L10N.register(
     "Install Mailvelope browser extension by clicking here" : "Instala la extensión del navegador Mailvelope haciendo clic aquí",
     "Enable Mailvelope for the current domain" : "Habilita Mailvelope para el dominio actual",
     "Assistance features" : "Características de asistencia",
+    "About" : "Acerca",
     "Keyboard shortcuts" : "Atajos del teclado",
     "Compose new message" : "Escribir mensaje nuevo",
     "Newer message" : "Mensaje más nuevo",
@@ -154,21 +161,25 @@ OC.L10N.register(
     "Search" : "Buscar",
     "Send" : "Enviar",
     "Refresh" : "Actualizar",
-    "Search in the body of messages in priority Inbox" : "Busca en el cuerpo de los mensajes de la bandeja de entrada prioritaria",
-    "Activate" : "Activar",
-    "Put my text to the bottom of a reply instead of on top of it." : "Pon el texto al fondo de una respuesta, en lugar de arriba.",
-    "Mark as important" : "Marcar como importante",
-    "Remind about messages that require a reply but received none" : "Recordar mensajes que requieren una respuesta pero no han recibido ninguna",
-    "Use internal addresses" : "Usar direcciones internas",
-    "Could not update preference" : "No se pudo actualizar la preferencia",
-    "Select an alias" : "Selecciona un alias",
-    "Select certificates" : "Selecciona certificados",
-    "Update Certificate" : "Actualizar certificado",
-    "The selected certificate is not trusted by the server. Recipients might not be able to verify your signature." : "El certificado seleccionado no es de confianza para el servidor. Los destinatarios podrían no ser capaces de verificar tu firma.",
     "No certificate" : "Sin certificado",
     "Certificate updated" : "Certificado actualizado",
     "Could not update certificate" : "No se pudo actualizar el certificado",
     "{commonName} - Valid until {expiryDate}" : "{commonName} - Válido hasta {expiryDate}",
+    "Select an alias" : "Selecciona un alias",
+    "Select certificates" : "Selecciona certificados",
+    "Update Certificate" : "Actualizar certificado",
+    "The selected certificate is not trusted by the server. Recipients might not be able to verify your signature." : "El certificado seleccionado no es de confianza para el servidor. Los destinatarios podrían no ser capaces de verificar tu firma.",
+    "Encrypt with S/MIME and send later" : "Encriptar con S/MIME y enviar más tarde",
+    "Encrypt with S/MIME and send" : "Encriptar con S/MIME y enviar",
+    "Encrypt with Mailvelope and send later" : "Encriptar con Mailvelope y enviar más tarde",
+    "Encrypt with Mailvelope and send" : "Encriptar con Mailvelope y enviar",
+    "Send later" : "Enviar más tarde",
+    "Message {id} could not be found" : "No se pudo encontrar el mensaje {id}",
+    "Sign or Encrypt with S/MIME was selected, but we don't have a certificate for the selected alias. The message will not be signed or encrypted." : "Se seleccionó Firmar o Encriptar con S/MIME, pero no tenemos un certificado para el alias seleccionado. El mensaje no sera firmado ni encriptado.",
+    "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "Cualquier formato existente (por ejemplo, negrita, cursiva, subrayado o imágenes en línea) se eliminará.",
+    "Turn off formatting" : "Desactivar formato",
+    "Turn off and remove formatting" : "Desactivar y remover formato",
+    "Keep formatting" : "Conservar formato",
     "From" : "De",
     "Select account" : "Selecciona la cuenta",
     "To" : "Para",
@@ -194,7 +205,6 @@ OC.L10N.register(
     "Add attachment from Files" : "Agregar adjunto desd Archivos",
     "Add share link from Files" : "Agregar un enlace adjunto desde Archivos",
     "Smart picker" : "Selector inteligente",
-    "Send later" : "Enviar más tarde",
     "Request a read receipt" : "Solicitar confirmación de lectura",
     "Sign message with S/MIME" : "Firmar mensaje con S/MIME",
     "Encrypt message with S/MIME" : "Encriptar mensaje con S/MIME",
@@ -205,31 +215,34 @@ OC.L10N.register(
     "Monday morning" : "Lunes por la mañana",
     "Custom date and time" : "Fecha y hora personalizada",
     "Enter a date" : "Ingrese una fecha",
-    "Encrypt with S/MIME and send later" : "Encriptar con S/MIME y enviar más tarde",
-    "Encrypt with S/MIME and send" : "Encriptar con S/MIME y enviar",
-    "Encrypt with Mailvelope and send later" : "Encriptar con Mailvelope y enviar más tarde",
-    "Encrypt with Mailvelope and send" : "Encriptar con Mailvelope y enviar",
-    "Message {id} could not be found" : "No se pudo encontrar el mensaje {id}",
-    "Sign or Encrypt with S/MIME was selected, but we don't have a certificate for the selected alias. The message will not be signed or encrypted." : "Se seleccionó Firmar o Encriptar con S/MIME, pero no tenemos un certificado para el alias seleccionado. El mensaje no sera firmado ni encriptado.",
-    "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "Cualquier formato existente (por ejemplo, negrita, cursiva, subrayado o imágenes en línea) se eliminará.",
-    "Turn off formatting" : "Desactivar formato",
-    "Turn off and remove formatting" : "Desactivar y remover formato",
-    "Keep formatting" : "Conservar formato",
+    "Choose" : "Seleccionar",
     "Choose a file to add as attachment" : "Selecciona el archivo a agregar como adjunto",
     "Choose a file to share as a link" : "Eligir un archivo para compartir como enlace",
-    "Choose" : "Seleccionar",
     "_{count} attachment_::_{count} attachments_" : ["{count} adjunto","{count} adjuntos","{count} adjuntos"],
+    "Untitled message" : "Mensaje sin título",
     "Expand composer" : "Expandir redactor",
     "Close composer" : "Cerrar redactor",
-    "Untitled message" : "Mensaje sin título",
     "Confirm" : "Confirmar",
-    "The tag will be deleted from all messages." : "La etiqueta se eliminará de todos los mensajes.",
     "Tag: {name} deleted" : "Etiqueta: {name} eliminada",
     "An error occurred, unable to delete the tag." : "Ha ocurrido un error, no se ha podido eliminar la etiqueta.",
+    "The tag will be deleted from all messages." : "La etiqueta se eliminará de todos los mensajes.",
     "Plain text" : "Texto plano",
     "Rich text" : "Texto enriquecido",
     "No messages in this mailbox" : "No hay mensajes en este buzón de correo",
     "No messages" : "Sin mensajes",
+    "Blind copy recipients only" : "Solo destinatarios de copia oculta",
+    "No subject" : "Sin asunto",
+    "Set reminder for later today" : "Configurar recordatorio para hoy, más tarde",
+    "Set reminder for tomorrow" : "Configurar recordatorio para mañana",
+    "Set reminder for this weekend" : "Configurar recordatorio para este fin de semana",
+    "Set reminder for next week" : "Configurar recordatorio para la próxima semana",
+    "No trash mailbox configured" : "No se ha configurado un buzón de papelera",
+    "Could not delete message" : "No se pudo eliminar el mensaje",
+    "Could not archive message" : "No se pudo archivar el mensaje",
+    "Thread was snoozed" : "El hilo ha sido pausado",
+    "Could not snooze thread" : "No se ha podido pausar el hilo",
+    "Thread was unsnoozed" : "El hilo fue reanudado",
+    "Could not unsnooze thread" : "No se pudo reanudar el hilo",
     "Draft: " : "Borrador:",
     "Encrypted message" : "Mensaje encriptado",
     "This message is unread" : "Este mensaje no ha sido leído",
@@ -253,27 +266,20 @@ OC.L10N.register(
     "Create event" : "Crear evento",
     "Create task" : "Crear tarea",
     "Download message" : "Descargar mensaje",
-    "Blind copy recipients only" : "Solo destinatarios de copia oculta",
-    "No subject" : "Sin asunto",
-    "Set reminder for later today" : "Configurar recordatorio para hoy, más tarde",
-    "Set reminder for tomorrow" : "Configurar recordatorio para mañana",
-    "Set reminder for this weekend" : "Configurar recordatorio para este fin de semana",
-    "Set reminder for next week" : "Configurar recordatorio para la próxima semana",
-    "No trash mailbox configured" : "No se ha configurado un buzón de papelera",
-    "Could not delete message" : "No se pudo eliminar el mensaje",
-    "Could not archive message" : "No se pudo archivar el mensaje",
-    "Thread was snoozed" : "El hilo ha sido pausado",
-    "Could not snooze thread" : "No se ha podido pausar el hilo",
-    "Thread was unsnoozed" : "El hilo fue reanudado",
-    "Could not unsnooze thread" : "No se pudo reanudar el hilo",
     "Load more" : "Cargar más",
     "Report this bug" : "Reportar este bug",
+    "Event created" : "Evento creado",
+    "Could not create event" : "No se pudo crear el evento",
     "All day" : "Todo el día",
     "Select calendar" : "Seleccionar calendario",
     "Description" : "Descripción",
     "Create" : "Crear",
-    "Event created" : "Evento creado",
-    "Could not create event" : "No se pudo crear el evento",
+    "This event was updated" : "Este evento fue actualizado",
+    "{attendeeName} accepted your invitation" : "{attendeeName} aceptó tu invitación",
+    "{attendeeName} tentatively accepted your invitation" : "{attendeeName} aceptó tentativamente tu invitación",
+    "{attendeeName} declined your invitation" : "{attendeeName} rechazó tu invitación",
+    "{attendeeName} reacted to your invitation" : "{attendeeName} reaccionó a tu invitación",
+    "Failed to save your participation status" : "Error al guardar tu estado de participación",
     "You accepted this invitation" : "Has aceptado esta invitación",
     "You tentatively accepted this invitation" : "Has aceptado tentativamente esta invitación",
     "You declined this invitation" : "Has rechazado esta invitación",
@@ -287,27 +293,20 @@ OC.L10N.register(
     "Decline" : "Rechazar",
     "Tentatively accept" : "Aceptar tentativamente",
     "More options" : "Más opciones",
-    "This event is in the past." : "Este evento fue en el pasado.",
-    "This event was updated" : "Este evento fue actualizado",
-    "{attendeeName} accepted your invitation" : "{attendeeName} aceptó tu invitación",
-    "{attendeeName} tentatively accepted your invitation" : "{attendeeName} aceptó tentativamente tu invitación",
-    "{attendeeName} declined your invitation" : "{attendeeName} rechazó tu invitación",
-    "{attendeeName} reacted to your invitation" : "{attendeeName} reaccionó a tu invitación",
-    "Failed to save your participation status" : "Error al guardar tu estado de participación",
+    "Could not remove internal address {sender}" : "No se pudo remover la dirección interna {sender}",
+    "Could not add internal address {address}" : "No se pudo agregar la dirección interna {address}",
+    "individual" : "individual",
     "domain" : "dominio",
     "Remove" : "Eliminar",
     "email" : "correo electrónico",
     "Add internal address" : "Agregar dirección interna",
     "Add internal email or domain" : "Agregar dirección de correo interna o dominio",
-    "Could not remove internal address {sender}" : "No se pudo remover la dirección interna {sender}",
-    "Could not add internal address {address}" : "No se pudo agregar la dirección interna {address}",
-    "individual" : "individual",
     "Itinerary for {type} is not supported yet" : "El itinerario para {type} aún no es soportado",
+    "To archive a message please configure an archive mailbox in account settings" : "Para archivar un mensaje, configura un buzón de archivado en las configuraciones de la cuenta",
+    "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "No tienes permiso para mover este mensaje al buzón de archivado y/o eliminar este mensaje de la carpeta actual",
     "Could not open mailbox" : "No se pudo abrir el buzón",
     "Loading messages …" : "Cargando mensajes...",
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indizando tus mensajes. Esto puede tardar un poco para buzones grandes.",
-    "To archive a message please configure an archive mailbox in account settings" : "Para archivar un mensaje, configura un buzón de archivado en las configuraciones de la cuenta",
-    "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "No tienes permiso para mover este mensaje al buzón de archivado y/o eliminar este mensaje de la carpeta actual",
     "Choose target mailbox" : "Escoger buzón de destino",
     "No more submailboxes in here" : "No hay más sub-buzones aquí",
     "Follow up" : "Seguimiento",
@@ -315,46 +314,50 @@ OC.L10N.register(
     "Important info" : "Información importante",
     "Other" : "Otro",
     "Forward" : "Adelante",
+    "Translate" : "Traducir",
+    "Unnamed" : "Sin nombre",
     "Choose a folder to store the attachment in" : "Seleccciona la carpeta en la cual almacenar el adjunto",
     "Import into calendar" : "Importar al calendario",
     "Download attachment" : "Descargar adjunto",
     "Save to Files" : "Guardar a Archivos",
-    "Unnamed" : "Sin nombre",
     "Save all to Files" : "Guardar todo a Archivos",
     "The images have been blocked to protect your privacy." : "Las imágenes han sido bloqueadas para proteger tu privacidad. ",
     "Quoted text" : "Texto citado",
     "Move" : "Mover",
+    "Loading …" : "Cargando …",
+    "Remove account" : "Eliminar cuenta",
     "Quota" : "Cuota",
     "Saving" : "Guardando",
     "Move up" : "Mover arriba",
     "Move down" : "Mover abajo",
-    "Remove account" : "Eliminar cuenta",
-    "Loading …" : "Cargando …",
+    "Clear mailbox" : "Vaciar buzón",
     "Mark all as read" : "Marcar todos como leídos",
     "Rename" : "Renombrar",
     "Clear cache" : "Borrar el caché",
     "Subscribed" : "Suscrito",
-    "Clear mailbox" : "Vaciar buzón",
     "New message" : "Mensaje nuevo",
+    "Reply" : "Responder",
     "Retry" : "Reintentar",
     "Sending …" : "Enviando ...",
-    "Reply" : "Responder",
     "First day" : "Primer día",
     "Message" : "Mensaje",
     "Copy to clipboard" : "Copiar al portapapeles",
     "Add" : "Agregar",
+    "Show less" : "Mostrar menos",
+    "Show more" : "Mostrar más",
+    "Clear" : "Limpiar",
     "Close" : "Cerrar",
     "Date" : "Fecha",
     "Tags" : "Etiquetas",
     "Select tags" : "Selecciona las etiquetas",
     "Last 7 days" : "Últimos 7 días",
-    "Clear" : "Limpiar",
     "Custom" : "Personalizado",
-    "Add tag" : "Agregar etiqueta",
     "Tag already exists" : "La etiqueta ya existe",
+    "Add tag" : "Agregar etiqueta",
     "Not found" : "No encontrado",
-    "(organizer)" : "(organizador)",
+    "Translate from" : "Traducir desde",
     "Untitled event" : "Evento sin título",
+    "(organizer)" : "(organizador)",
     "Operator" : "Operador",
     "Actions" : "Acciones",
     "Priority" : "Prioridad",
@@ -392,6 +395,6 @@ OC.L10N.register(
     "Redirect" : "Redireccionar",
     "The link leads to %s" : "La liga lleva a %s",
     "Continue to %s" : "Continuar a %s",
-    "Unselect" : "Deseleccionar"
+    "This event is in the past." : "Este evento fue en el pasado."
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
