@@ -18,6 +18,27 @@ OC.L10N.register(
     "Sent messages are saved in:" : "Išsiųsti laiškai yra įrašomi į:",
     "Deleted messages are moved in:" : "Ištrinti laiškai yra perkeliami į:",
     "Archived messages are moved in:" : "Archyvuoti laiškai yra perkeliami į:",
+    "Connecting" : "Jungiamasi",
+    "Reconnect Google account" : "Iš naujo prijungti „Google“ paskyrą",
+    "Sign in with Google" : "Prisijungti naudojant „Google“",
+    "Reconnect Microsoft account" : "Iš naujo prijungti „Microsoft“ paskyrą",
+    "Sign in with Microsoft" : "Prisijungti naudojant „Microsoft“",
+    "Save" : "Įrašyti",
+    "Connect" : "Prisijungti",
+    "Looking up configuration" : "Ieškoma konfigūracijos",
+    "Checking mail host connectivity" : "Tikrinamas jungiamumas su pašto serveriu",
+    "Configuration discovery failed. Please use the manual settings" : "Nepavyko atrasti konfigūracijos. Naudokite rankinius nustatymus",
+    "Password required" : "Reikalingas slaptažodis",
+    "Testing authentication" : "Išbandomas tapatybės nustatymas",
+    "Awaiting user consent" : "Laukiama naudotojo sutikimo",
+    "Account updated" : "Paskyra atnaujinta",
+    "IMAP server is not reachable" : "IMAP serveris yra nepasiekiamas",
+    "SMTP server is not reachable" : "SMTP serveris yra nepasiekiamas",
+    "IMAP username or password is wrong" : "Neteisingas IMAP naudotojo vardas ar slaptažodis",
+    "SMTP username or password is wrong" : "Neteisingas SMTP naudotojo vardas ar slaptažodis",
+    "IMAP connection failed" : "IMAP ryšys patyrė nesėkmę",
+    "SMTP connection failed" : "SMTP ryšys patyrė nesėkmę",
+    "There was an error while setting up your account" : "Nustatant jūsų paskyrą įvyko klaida",
     "Auto" : "Automatiškai",
     "Name" : "Vardas",
     "Mail address" : "El. pašto adresas",
@@ -38,24 +59,6 @@ OC.L10N.register(
     "SMTP Port" : "SMTP prievadas",
     "SMTP User" : "SMTP naudotojo vardas",
     "SMTP Password" : "SMTP slaptažodis",
-    "Connecting" : "Jungiamasi",
-    "Reconnect Google account" : "Iš naujo prijungti „Google“ paskyrą",
-    "Sign in with Google" : "Prisijungti naudojant „Google“",
-    "Save" : "Įrašyti",
-    "Connect" : "Prisijungti",
-    "Looking up configuration" : "Ieškoma konfigūracijos",
-    "Checking mail host connectivity" : "Tikrinamas jungiamumas su pašto serveriu",
-    "Configuration discovery failed. Please use the manual settings" : "Nepavyko atrasti konfigūracijos. Naudokite rankinius nustatymus",
-    "Password required" : "Reikalingas slaptažodis",
-    "Testing authentication" : "Išbandomas tapatybės nustatymas",
-    "Account updated" : "Paskyra atnaujinta",
-    "IMAP server is not reachable" : "IMAP serveris yra nepasiekiamas",
-    "SMTP server is not reachable" : "SMTP serveris yra nepasiekiamas",
-    "IMAP username or password is wrong" : "Neteisingas IMAP naudotojo vardas ar slaptažodis",
-    "SMTP username or password is wrong" : "Neteisingas SMTP naudotojo vardas ar slaptažodis",
-    "IMAP connection failed" : "IMAP ryšys patyrė nesėkmę",
-    "SMTP connection failed" : "SMTP ryšys patyrė nesėkmę",
-    "There was an error while setting up your account" : "Nustatant jūsų paskyrą įvyko klaida",
     "Account settings" : "Paskyros nustatymai",
     "Aliases" : "Pseudonimai",
     "Signature" : "Parašas",
@@ -64,12 +67,15 @@ OC.L10N.register(
     "Preferred writing mode for new messages and replies." : "Pageidaujama rašymo veiksena naujuose laiškuose ir atsakant į laiškus.",
     "Default folders" : "Numatytieji aplankai",
     "Autoresponder" : "Atsakiklis",
+    "Filters" : "Filtrai",
     "Mail server" : "Pašto serveris",
     "Go back" : "Grįžti",
     "Change name" : "Keisti vardą",
     "Email address" : "El. pašto adresas",
     "Add alias" : "Pridėti alternatyvų vardą",
     "Cancel" : "Atsisakyti",
+    "Use internal addresses" : "Naudoti vidinius adresus",
+    "Could not update preference" : "Nepavyko atnaujinti nuostatos",
     "Mail settings" : "Pašto nustatymai",
     "Accounts" : "Paskyros",
     "Add mail account" : "Pridėti pašto paskyrą",
@@ -89,6 +95,7 @@ OC.L10N.register(
     "S/MIME" : "S/MIME",
     "Manage S/MIME certificates" : "Tvarkyti S/MIME liudijimus",
     "Looking for a way to encrypt your emails?" : "Ieškote būdo šifruoti el. laiškus?",
+    "About" : "Apie",
     "Keyboard shortcuts" : "Spartieji klavišai",
     "Compose new message" : "Rašyti naują laišką",
     "Newer message" : "Naujesni laiškai",
@@ -100,10 +107,17 @@ OC.L10N.register(
     "Search" : "Ieškoti",
     "Send" : "Siųsti",
     "Refresh" : "Įkelti iš naujo",
-    "Could not update preference" : "Nepavyko atnaujinti nuostatos",
     "Certificate updated" : "Liudijimas atnaujintas",
     "Could not update certificate" : "Nepavyko atnaujinti liudijimo",
     "{commonName} - Valid until {expiryDate}" : "{commonName} – Galioja iki {expiryDate}",
+    "Encrypt with S/MIME and send later" : "Šifruoti naudojant S/MIME ir siųsti vėliau",
+    "Encrypt with S/MIME and send" : "Šifruoti naudojant S/MIME ir siųsti",
+    "Encrypt with Mailvelope and send later" : "Šifruoti naudojant Mailvelope ir siųsti vėliau",
+    "Encrypt with Mailvelope and send" : "Šifruoti naudojant Mailvelope ir siųsti",
+    "Send later" : "Siųsti vėliau",
+    "Turn off formatting" : "Išjungti formatavimą",
+    "Turn off and remove formatting" : "Išjungti ir šalinti formatavimą",
+    "Keep formatting" : "Palikti formatavimą",
     "From" : "Nuo",
     "Select account" : "Pasirinkti paskyrą",
     "To" : "Kam",
@@ -125,38 +139,41 @@ OC.L10N.register(
     "Disable formatting" : "Išjungti formatavimą",
     "Upload attachment" : "Įkelti priedą",
     "Add attachment from Files" : "Pridėti priedą iš Failų",
-    "Send later" : "Siųsti vėliau",
     "Sign message with S/MIME" : "Pasirašyti laišką naudojant S/MIME",
     "Encrypt message with S/MIME" : "Šifruoti laišką naudojant S/MIME",
     "Encrypt message with Mailvelope" : "Šifruoti laišką naudojant Mailvelope",
     "Send now" : "Siųsti dabar",
     "Custom date and time" : "Tinkinta data ir laikas",
     "Enter a date" : "Įveskite datą",
-    "Encrypt with S/MIME and send later" : "Šifruoti naudojant S/MIME ir siųsti vėliau",
-    "Encrypt with S/MIME and send" : "Šifruoti naudojant S/MIME ir siųsti",
-    "Encrypt with Mailvelope and send later" : "Šifruoti naudojant Mailvelope ir siųsti vėliau",
-    "Encrypt with Mailvelope and send" : "Šifruoti naudojant Mailvelope ir siųsti",
-    "Turn off formatting" : "Išjungti formatavimą",
-    "Turn off and remove formatting" : "Išjungti ir šalinti formatavimą",
-    "Keep formatting" : "Palikti formatavimą",
+    "Choose" : "Pasirinkite",
     "Choose a file to add as attachment" : "Pasirinkite failą, kurį prisegsite prie laiško",
     "Choose a file to share as a link" : "Pasirinkite failą, kurį bendrinsite kaip nuorodą",
-    "Choose" : "Pasirinkite",
     "_{count} attachment_::_{count} attachments_" : ["{count} priedas","{count} priedai","{count} priedų","{count} priedas"],
     "Confirm" : "Patvirtinti",
-    "Tag: {name} deleted" : "Žymė: {name} ištrinta",
-    "An error occurred, unable to delete the tag." : "Įvyko klaida, nepavyko ištrinti žymės.",
+    "Tag: {name} deleted" : "Žyma: {name} ištrinta",
+    "An error occurred, unable to delete the tag." : "Įvyko klaida, nepavyko ištrinti žymos.",
     "Plain text" : "Grynasis tekstas",
     "Rich text" : "Raiškusis tekstas",
     "No messages in this mailbox" : "Šioje pašto dėžutėje laiškų nėra",
     "No messages" : "Nėra laiškų",
+    "No subject" : "Be temos",
+    "Later today – {timeLocale}" : "Šiandien vėliau – {timeLocale}",
+    "Set reminder for later today" : "Nustatyti priminimą šiandien vėliau",
+    "Tomorrow – {timeLocale}" : "Rytoj – {timeLocale}",
+    "Set reminder for tomorrow" : "Nustatyti priminimą rytoj",
+    "This weekend – {timeLocale}" : "Šį savaitgalį – {timeLocale}",
+    "Set reminder for this weekend" : "Nustatyti priminimą šį savaitgalį",
+    "Next week – {timeLocale}" : "Kitą savaitę – {timeLocale}",
+    "Set reminder for next week" : "Nustatyti priminimą kitą savaitę",
+    "Could not delete message" : "Nepavyko ištrinti laiško",
+    "Could not archive message" : "Nepavyko archyvuoti laiško",
     "Draft: " : "Juodraštis: ",
     "Encrypted message" : "Šifruotas laiškas",
     "This message is unread" : "Šis laiškas yra neskaitytas",
     "Unfavorite" : "Nebežymėti kaip mėgstamą",
     "Favorite" : "Mėgstamas",
     "Read" : "Skaityti",
-    "Edit tags" : "Redaguoti žymes",
+    "Edit tags" : "Taisyti žymas",
     "Move thread" : "Perkelti giją",
     "Archive thread" : "Archyvuoti giją",
     "Delete thread" : "Ištrinti giją",
@@ -166,37 +183,31 @@ OC.L10N.register(
     "Create event" : "Sukurti įvykį",
     "Create task" : "Sukurti užduotį",
     "Download message" : "Atsisiųsti laišką",
-    "No subject" : "Be temos",
-    "Set reminder for later today" : "Nustatyti priminimą šiandien vėliau",
-    "Set reminder for tomorrow" : "Nustatyti priminimą rytoj",
-    "Set reminder for this weekend" : "Nustatyti priminimą šį savaitgalį",
-    "Set reminder for next week" : "Nustatyti priminimą kitą savaitę",
-    "Could not delete message" : "Nepavyko ištrinti laiško",
-    "Could not archive message" : "Nepavyko archyvuoti laiško",
     "Load more" : "Įkelti daugiau",
     "_Mark {number} read_::_Mark {number} read_" : ["Žymėti {number} kaip skaitytą","Žymėti {number} kaip skaitytus","Žymėti {number} kaip skaitytus","Žymėti {number} kaip skaitytą"],
     "_Mark {number} unread_::_Mark {number} unread_" : ["Žymėti {number} kaip neskaitytą","Žymėti {number} kaip neskaitytus","Žymėti {number} kaip neskaitytus","Žymėti {number} kaip neskaitytą"],
     "Report this bug" : "Pranešti apie šią klaidą",
+    "Event created" : "Įvykis sukurtas",
+    "Could not create event" : "Nepavyko sukurti įvykio",
     "All day" : "Visą dieną",
     "Description" : "Aprašas",
     "Create" : "Sukurti",
-    "Event created" : "Įvykis sukurtas",
-    "Could not create event" : "Nepavyko sukurti įvykio",
+    "This event was updated" : "Šis įvykis buvo atnaujintas",
+    "{attendeeName} accepted your invitation" : "{attendeeName} priėmė jūsų pakvietimą",
+    "{attendeeName} declined your invitation" : "{attendeeName} atmetė jūsų pakvietimą",
+    "You accepted this invitation" : "Jūs priėmėte šį pakvietimą",
+    "You declined this invitation" : "Jūs atmetėte šį pakvietimą",
     "Save to" : "Įrašyti į",
     "Select" : "Pasirinkti",
     "Comment" : "Komentaras",
     "Accept" : "Priimti",
     "Decline" : "Atmesti",
     "More options" : "Daugiau parinkčių",
-    "This event is in the past." : "Šis įvykis yra praeityje.",
-    "This event was updated" : "Šis įvykis buvo atnaujintas",
-    "{attendeeName} accepted your invitation" : "{attendeeName} priėmė jūsų pakvietimą",
-    "{attendeeName} declined your invitation" : "{attendeeName} atmetė jūsų pakvietimą",
+    "Could not remove internal address {sender}" : "Nepavyko pašalinti vidinio adreso {sender}",
+    "Could not add internal address {address}" : "Nepavyko pridėti vidinį adresą {address}",
     "Remove" : "Šalinti",
     "email" : "elektroninis paštas",
     "Add internal address" : "Pridėti vidinį adresą",
-    "Could not remove internal address {sender}" : "Nepavyko pašalinti vidinio adreso {sender}",
-    "Could not add internal address {address}" : "Nepavyko pridėti vidinį adresą {address}",
     "Could not open mailbox" : "Nepavyko atverti pašto dėžutės",
     "Loading messages …" : "Įkeliami laiškai…",
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indeksuojami jūsų laiškai. Didelėse pašto dėžutėse tai gali užtrukti šiek tiek ilgiau.",
@@ -207,20 +218,21 @@ OC.L10N.register(
     "You sent a read confirmation to the sender of this message." : "Jūs išsiuntėte šio laiško siuntėjui patvirtinimą, kad perskaitėte jo laišką.",
     "Forward" : "Persiųsti",
     "Move message" : "Perkelti laišką",
+    "Translate" : "Verskite",
     "Forward message as attachment" : "Persiųsti laišką kaip priedą",
     "Message body" : "Pagrindinė laiško dalis",
-    "Choose a folder to store the attachment in" : "Pasirinkite aplanką, kuriame išsaugoti priedą",
-    "Import into calendar" : "Importuoti į kalendorių",
-    "Download attachment" : "Atsisiųsti priedą",
-    "Save to Files" : "Įrašyti į Failus",
     "Unnamed" : "Be pavadinimo",
     "Embedded message" : "Įterptas laiškas",
     "Attachment could not be saved" : "Nepavyko įrašyti priedo",
     "calendar imported" : "kalendorius importuotas",
+    "Choose a folder to store the attachment in" : "Pasirinkite aplanką, kuriame išsaugoti priedą",
+    "Import into calendar" : "Importuoti į kalendorių",
+    "Download attachment" : "Atsisiųsti priedą",
+    "Save to Files" : "Įrašyti į Failus",
+    "Error while saving attachments" : "Klaida įrašant priedus",
     "View fewer attachments" : "Rodyti mažiau priedų",
     "Choose a folder to store the attachments in" : "Pasirinkite aplanką, kuriame laikyti priedus",
     "Save all to Files" : "Įrašyti visus į Failus",
-    "Error while saving attachments" : "Klaida įrašant priedus",
     "_View {count} more attachment_::_View {count} more attachments_" : ["Rodyti dar {count} priedą","Rodyti dar {count} priedus","Rodyti dar {count} priedų","Rodyti dar {count} priedą"],
     "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "Šis laiškas yra šifruotas naudojant PGP. Norėdami jį iššifruoti, įsidiekite Mailvelope.",
     "The images have been blocked to protect your privacy." : "Tam, kad būtų apsaugotas jūsų privatumas, paveikslai buvo užblokuoti.",
@@ -230,6 +242,12 @@ OC.L10N.register(
     "Always show images from {domain}" : "Visada rodyti paveikslus iš {domain}",
     "Quoted text" : "Cituojamas tekstas",
     "Move" : "Perkelti",
+    "Loading …" : "Įkeliama…",
+    "Not supported by the server" : "Serveris nepalaiko",
+    "{usage} of {limit} used" : "Panaudota {usage} iš {limit}",
+    "Remove account" : "Šalinti paskyrą",
+    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Paskyra {email} ir podėlyje esantys el. pašto duomenys bus pašalinti iš Nextcloud, tačiau nebus pašalinti iš jūsų el. pašto teikėjo puslapio.",
+    "Remove {email}" : "Šalinti {email}",
     "Quota" : "Leidžiamas duomenų kiekis",
     "Show only subscribed mailboxes" : "Rodyti tik prenumeruotas pašto dėžutes",
     "Add mailbox" : "Pridėti pašto dėžutę",
@@ -237,15 +255,18 @@ OC.L10N.register(
     "Saving" : "Įrašoma",
     "Move up" : "Pakelti",
     "Move down" : "Nuleisti",
-    "Remove account" : "Šalinti paskyrą",
-    "Loading …" : "Įkeliama…",
-    "Not supported by the server" : "Serveris nepalaiko",
-    "{usage} of {limit} used" : "Panaudota {usage} iš {limit}",
-    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Paskyra {email} ir podėlyje esantys el. pašto duomenys bus pašalinti iš Nextcloud, tačiau nebus pašalinti iš jūsų el. pašto teikėjo puslapio.",
-    "Remove {email}" : "Šalinti {email}",
     "Show all subscribed mailboxes" : "Rodyti visas prenumeruotas pašto dėžutes",
     "Show all mailboxes" : "Rodyti visas pašto dėžutes",
     "Collapse mailboxes" : "Suskleisti pašto dėžutes",
+    "_{total} message_::_{total} messages_" : ["{total} laiškas","{total} laiškai","{total} laiškų","{total} laiškas"],
+    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} neskaitytas iš {total}","{unread} neskaityti iš {total}","{unread} neskaitytų iš {total}","{unread} neskaitytas iš {total}"],
+    "All messages in mailbox will be deleted." : "Visi pašto dėžutėje esantys laiškai bus ištrinti.",
+    "Clear mailbox {name}" : "Išvalyti pašto dėžutę {name}",
+    "Clear mailbox" : "Išvalyti pašto dėžutę",
+    "The mailbox and all messages in it will be deleted." : "Pašto dėžutė ir visi joje esantys laiškai bus ištrinti.",
+    "Delete mailbox" : "Ištrinti pašto dėžutę",
+    "Delete mailbox {name}" : "Ištrinti pašto dėžutę {name}",
+    "An error occurred, unable to rename the mailbox." : "Įvyko klaida, nepavyko pervadinti pašto dėžutės.",
     "Mark all as read" : "Žymėti visus kaip skaitytus",
     "Mark all messages of this mailbox as read" : "Žymėti visus laiškus šioje pašto dėžutėje kaip skaitytus",
     "Rename" : "Pervadinti",
@@ -253,20 +274,7 @@ OC.L10N.register(
     "Clear cache" : "Išvalyti podėlį",
     "Subscribed" : "Prenumeruotas",
     "Sync in background" : "Sinchronizuoti fone",
-    "Clear mailbox" : "Išvalyti pašto dėžutę",
-    "Delete mailbox" : "Ištrinti pašto dėžutę",
-    "All messages in mailbox will be deleted." : "Visi pašto dėžutėje esantys laiškai bus ištrinti.",
-    "Clear mailbox {name}" : "Išvalyti pašto dėžutę {name}",
-    "The mailbox and all messages in it will be deleted." : "Pašto dėžutė ir visi joje esantys laiškai bus ištrinti.",
-    "Delete mailbox {name}" : "Ištrinti pašto dėžutę {name}",
-    "An error occurred, unable to rename the mailbox." : "Įvyko klaida, nepavyko pervadinti pašto dėžutės.",
-    "_{total} message_::_{total} messages_" : ["{total} laiškas","{total} laiškai","{total} laiškų","{total} laiškas"],
     "New message" : "Naujas laiškas",
-    "Error sending your message" : "Klaida siunčiant jūsų laišką",
-    "Retry" : "Bandyti dar kartą",
-    "Uploading attachments …" : "Įkeliami priedai …",
-    "Sending …" : "Siunčiama …",
-    "Send anyway" : "Vis tiek siųsti",
     "Edit message" : "Taisyti laišką",
     "Draft" : "Juodraštis",
     "Reply" : "Atsakyti",
@@ -276,6 +284,11 @@ OC.L10N.register(
     "attachment" : "priedas",
     "Message discarded" : "Laiškas atmestas",
     "Could not discard message" : "Nepavyko atmesti laiško",
+    "Error sending your message" : "Klaida siunčiant jūsų laišką",
+    "Retry" : "Bandyti dar kartą",
+    "Uploading attachments …" : "Įkeliami priedai …",
+    "Sending …" : "Siunčiama …",
+    "Send anyway" : "Vis tiek siųsti",
     "Autoresponder off" : "Atsakiklis išjungtas",
     "Autoresponder on" : "Atsakiklis įjungtas",
     "Message" : "Žinutė",
@@ -286,35 +299,42 @@ OC.L10N.register(
     "Message deleted" : "Laiškas ištrintas",
     "Hide suspicious links" : "Slėpti įtartinas nuorodas",
     "Show suspicious links" : "Rodyti įtartinas nuorodas",
+    "Copied email address to clipboard" : "El. pašto adresas nukopijuotas į iškarpinę",
+    "Could not copy email address to clipboard" : "Nepavyko nukopijuoti el. pašto adreso į iškarpinę",
     "Contacts with this address" : "Adresatai turintys šį adresą",
     "New Contact" : "Naujas adresatas",
     "Copy to clipboard" : "Kopijuoti į iškarpinę",
     "Contact name …" : "Adresato vardas…",
     "Add" : "Pridėti",
-    "Copied email address to clipboard" : "El. pašto adresas nukopijuotas į iškarpinę",
-    "Could not copy email address to clipboard" : "Nepavyko nukopijuoti el. pašto adreso į iškarpinę",
+    "Show less" : "Rodyti mažiau",
+    "Show more" : "Rodyti daugiau",
+    "Clear" : "Išvalyti",
     "Search in mailbox" : "Ieškoti pašto dėžutėje",
     "Close" : "Užverti",
     "Date" : "Data",
-    "Tags" : "Žymės",
-    "Select tags" : "Pasirinkti žymes",
-    "Clear" : "Išvalyti",
+    "Tags" : "Žymos",
+    "Select tags" : "Pasirinkti žymas",
+    "Last 7 days" : "Paskutinės 7 dienos",
     "Custom" : "Tinkinti",
     "Signature …" : "Parašas…",
     "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Jūsų parašas yra didesnis nei 2 MB. Tai gali paveikti redaktoriaus našumą.",
     "Save signature" : "Įrašyti parašą",
-    "Delete tag" : "Ištrinti žymę",
-    "An error occurred, unable to rename the tag." : "Įvyko klaida, nepavyko pervadinti žymės.",
-    "Add default tags" : "Pridėti numatytąsias žymes",
-    "Add tag" : "Pridėti žymę",
-    "Saving tag …" : "Įrašoma žymė…",
-    "Tag name is a hidden system tag" : "Žymės pavadinimas yra paslėpta sistemos žymė",
-    "Tag already exists" : "Žymė jau yra",
-    "Tag name cannot be empty" : "Žymės pavadinimas negali būti tuščias",
-    "An error occurred, unable to create the tag." : "Įvyko klaida, nepavyko sukurti žymės.",
+    "An error occurred, unable to rename the tag." : "Įvyko klaida, nepavyko pervadinti žymos.",
+    "Delete tag" : "Ištrinti žymą",
+    "Tag name is a hidden system tag" : "Žymos pavadinimas yra paslėpta sistemos žyma",
+    "Tag already exists" : "Žyma jau yra",
+    "Tag name cannot be empty" : "Žymos pavadinimas negali būti tuščias",
+    "An error occurred, unable to create the tag." : "Įvyko klaida, nepavyko sukurti žymos.",
+    "Add default tags" : "Pridėti numatytąsias žymas",
+    "Add tag" : "Pridėti žymą",
+    "Saving tag …" : "Įrašoma žyma…",
+    "Task created" : "Užduotis sukurta",
+    "Could not create task" : "Nepavyko sukurti užduoties",
     "Not found" : "Nerasta",
-    "Unsubscribe" : "Atsisakyti prenumeratos",
+    "This message was encrypted by the sender before it was sent." : "Siuntėjas, prieš išsiųsdamas šį laišką, jį užšifravo.",
     "Reply all" : "Atsakyti visiems",
+    "Disable reminder" : "Išjungti priminimą",
+    "Unsubscribe" : "Atsisakyti prenumeratos",
     "Reply to sender only" : "Atsakyti tik siuntėjui",
     "Mark as unread" : "Žymėti kaip neskaitytą",
     "Mark as read" : "Žymėti kaip skaitytą",
@@ -322,22 +342,21 @@ OC.L10N.register(
     "Message source" : "Pirminis laiško kodas",
     "Unsubscribe via link" : "Atsisakyti prenumeratos per nuorodą",
     "Unsubscribe via email" : "Atsisakyti prenumeratos per el. paštą",
-    "This message was encrypted by the sender before it was sent." : "Siuntėjas, prieš išsiųsdamas šį laišką, jį užšifravo.",
-    "No senders are trusted at the moment." : "Šiuo metu nėra patikimų siuntėjų.",
     "Could not remove trusted sender {sender}" : "Nepavyko pašalinti patikimo siuntėjo {sender}",
-    "(organizer)" : "(organizatorius)",
+    "No senders are trusted at the moment." : "Šiuo metu nėra patikimų siuntėjų.",
     "Untitled event" : "Įvykis be pavadinimo",
+    "(organizer)" : "(organizatorius)",
     "Import into {calendar}" : "Importuoti į {calendar}",
     "Event imported into {calendar}" : "Įvykis importuotas į {calendar}",
+    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Skrydis {flightNr} iš {depAirport} į {arrAirport}",
     "Airplane" : "Lėktuvas",
     "Reservation {id}" : "Rezervacija {id}",
-    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Skrydis {flightNr} iš {depAirport} į {arrAirport}",
-    "Train" : "Traukinys",
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} iš {depStation} į {arrStation}",
     "Train from {depStation} to {arrStation}" : "Traukinys iš {depStation} į {arrStation}",
+    "Train" : "Traukinys",
     "Delete action" : "Ištrinti veiksmą",
-    "Delete mail filter {filterName}?" : "Ištrinti pašto filtrą {filterName}?",
     "Delete filter" : "Ištrinti filtrą",
+    "Delete mail filter {filterName}?" : "Ištrinti pašto filtrą {filterName}?",
     "New filter" : "Naujas filtras",
     "Filter saved" : "Filtras įrašytas",
     "Could not save filter" : "Nepavyko įrašyti filtro",
@@ -348,6 +367,7 @@ OC.L10N.register(
     "Priority" : "Pirmenybė",
     "Enable filter" : "Įjungti filtrą",
     "Save filter" : "Įrašyti filtrą",
+    "Error saving config" : "Klaida įrašant konfigūraciją",
     "Mail app" : "Pašto programėlė",
     "The mail app allows users to read mails on their IMAP accounts." : "Pašto programėlė leidžia naudotojams skaityti laiškus savo IMAP paskyrose.",
     "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Čia galite rasti egzemplioriaus masto nustatymus. Specifinius naudotojo nustatymus galite rasti pačioje programėlėje (apatiniame kairiajame kampe).",
@@ -355,16 +375,15 @@ OC.L10N.register(
     "Allow additional mail accounts" : "Leisti papildomas pašto paskyras",
     "Gmail integration" : "„Gmail“ integracija",
     "Microsoft integration" : "„Microsoft“ integracija",
-    "Error saving config" : "Klaida įrašant konfigūraciją",
     "The original message will be attached as a \"message/rfc822\" attachment." : "Pradinis laiškas bus pridėtas kaip priedas „message/rfc822“.",
     "Reset" : "Atstatyti",
-    "Client ID" : "Kliento ID",
-    "Client secret" : "Kliento paslaptis",
-    "Unlink" : "Atsieti",
     "Google integration configured" : "„Google“ integracija sukonfigūruota",
     "Could not configure Google integration" : "Nepavyko sukonfigūruoti „Google“ integracijos",
     "Google integration unlinked" : "„Google“ integracija atsieta",
     "Could not unlink Google integration" : "Nepavyko atsieti „Google“ integracijos",
+    "Client ID" : "Kliento ID",
+    "Client secret" : "Kliento paslaptis",
+    "Unlink" : "Atsieti",
     "Microsoft integration configured" : "„Microsoft“ integracija sukonfigūruota",
     "Could not configure Microsoft integration" : "Nepavyko sukonfigūruoti „Microsoft“ integracijos",
     "Microsoft integration unlinked" : "„Microsoft“ integracija atsieta",
@@ -380,6 +399,8 @@ OC.L10N.register(
     "SMTP" : "SMTP",
     "Save Config" : "Įrašyti konfigūraciją",
     "With the settings above, the app will create account settings in the following way:" : "Naudodama aukščiau esančius nustatymus, programėlė sukurs paskyrai nustatymus štai tokiu būdu: ",
+    "Certificate imported successfully" : "Liudijimas sėkmingai importuotas",
+    "Failed to import the certificate" : "Nepavyko importuoti liudijimo",
     "S/MIME certificates" : "S/MIME liudijimai",
     "Certificate name" : "Liudijimo pavadinimas",
     "E-mail address" : "El. pašto adresas",
@@ -391,16 +412,10 @@ OC.L10N.register(
     "PEM Certificate" : "PEM liudijimas",
     "Certificate" : "Liudijimas",
     "Submit" : "Pateikti",
-    "Certificate imported successfully" : "Liudijimas sėkmingai importuotas",
-    "Failed to import the certificate" : "Nepavyko importuoti liudijimo",
     "Account connected" : "Paskyra prijungta",
     "You can close this window" : "Galite užverti šį langą",
     "Connect your mail account" : "Priregistruoti elektroninio pašto paskyrą",
     "To add a mail account, please contact your administrator." : "Norėdami pridėti pašto paskyrą, susisiekite su savo administratoriumi.",
-    "Next week – {timeLocale}" : "Kitą savaitę – {timeLocale}",
-    "This weekend – {timeLocale}" : "Šį savaitgalį – {timeLocale}",
-    "Tomorrow – {timeLocale}" : "Rytoj – {timeLocale}",
-    "Later today – {timeLocale}" : "Šiandien vėliau – {timeLocale}",
     "All" : "Visos",
     "Drafts" : "Juodraščiai",
     "Favorites" : "Mėgstami",
@@ -420,7 +435,7 @@ OC.L10N.register(
     "Message sent" : "Laiškas išsiųstas",
     "Could not send message" : "Nepavyko išsiųsti laiško",
     "Could not load {tag}{name}{endtag}" : "Nepavyko įkelti {tag}{name}{endtag}",
-    "There was a problem loading {tag}{name}{endtag}" : "Įvyko klaida bandant parodyti {tag}{name}{endtag}",
+    "There was a problem loading {tag}{name}{endtag}" : "Atsirado problemų įkeliant {tag}{name}{endtag}",
     "Could not load your message" : "Nepavyko įkelti jūsų laiško",
     "Could not load the desired message" : "Nepavyko įkelti pageidaujamo laiško",
     "Could not load the message" : "Nepavyko įkelti laiško",
@@ -430,7 +445,6 @@ OC.L10N.register(
     "Redirect" : "Peradresuoti",
     "The link leads to %s" : "Nuoroda veda į %s",
     "Continue to %s" : "Tęsti į %s",
-    "Account creation" : "Paskyros sukūrimas",
-    "Unselect" : "Nuimti žymėjimą"
+    "This event is in the past." : "Šis įvykis yra praeityje."
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
